package com.zehong.system.service.impl;

import java.util.List;
import com.zehong.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.zehong.system.mapper.TGasBottleTrackRecordMapper;
import com.zehong.system.domain.TGasBottleTrackRecord;
import com.zehong.system.service.ITGasBottleTrackRecordService;

/**
 * 气瓶追溯Service业务层处理
 * 
 * @author zehong
 * @date 2023-08-18
 */
@Service
public class TGasBottleTrackRecordServiceImpl implements ITGasBottleTrackRecordService 
{
    @Autowired
    private TGasBottleTrackRecordMapper tGasBottleTrackRecordMapper;

    /**
     * 查询气瓶追溯
     * 
     * @param trackRecordId 气瓶追溯ID
     * @return 气瓶追溯
     */
    @Override
    public TGasBottleTrackRecord selectTGasBottleTrackRecordById(Long trackRecordId)
    {
        return tGasBottleTrackRecordMapper.selectTGasBottleTrackRecordById(trackRecordId);
    }

    /**
     * 查询气瓶追溯列表
     * 
     * @param tGasBottleTrackRecord 气瓶追溯
     * @return 气瓶追溯
     */
    @Override
    public List<TGasBottleTrackRecord> selectTGasBottleTrackRecordList(TGasBottleTrackRecord tGasBottleTrackRecord)
    {
        return tGasBottleTrackRecordMapper.selectTGasBottleTrackRecordList(tGasBottleTrackRecord);
    }

    /**
     * 新增气瓶追溯
     * 
     * @param tGasBottleTrackRecord 气瓶追溯
     * @return 结果
     */
    @Override
    public int insertTGasBottleTrackRecord(TGasBottleTrackRecord tGasBottleTrackRecord)
    {
        tGasBottleTrackRecord.setCreateTime(DateUtils.getNowDate());
        return tGasBottleTrackRecordMapper.insertTGasBottleTrackRecord(tGasBottleTrackRecord);
    }

    /**
     * 修改气瓶追溯
     * 
     * @param tGasBottleTrackRecord 气瓶追溯
     * @return 结果
     */
    @Override
    public int updateTGasBottleTrackRecord(TGasBottleTrackRecord tGasBottleTrackRecord)
    {
        tGasBottleTrackRecord.setUpdateTime(DateUtils.getNowDate());
        return tGasBottleTrackRecordMapper.updateTGasBottleTrackRecord(tGasBottleTrackRecord);
    }

    /**
     * 批量删除气瓶追溯
     * 
     * @param trackRecordIds 需要删除的气瓶追溯ID
     * @return 结果
     */
    @Override
    public int deleteTGasBottleTrackRecordByIds(Long[] trackRecordIds)
    {
        return tGasBottleTrackRecordMapper.deleteTGasBottleTrackRecordByIds(trackRecordIds);
    }

    /**
     * 删除气瓶追溯信息
     * 
     * @param trackRecordId 气瓶追溯ID
     * @return 结果
     */
    @Override
    public int deleteTGasBottleTrackRecordById(Long trackRecordId)
    {
        return tGasBottleTrackRecordMapper.deleteTGasBottleTrackRecordById(trackRecordId);
    }
}
